Learn R Programming

plsRcox (version 1.8.2)

coxplsDR: Fitting a PLSR model on the (Deviance) Residuals

Description

This function computes the Cox Model based on PLSR components computed model with

  • as the response: the Residuals of a Cox-Model fitted with no covariate

  • as explanatory variables: Xplan.

It uses the package mixOmics to perform PLSR fit.

Usage

coxplsDR(Xplan, ...)

# S3 method for default coxplsDR( Xplan, time, time2, event, type, origin, typeres = "deviance", collapse, weighted, scaleX = TRUE, scaleY = TRUE, ncomp = min(7, ncol(Xplan)), modepls = "regression", plot = FALSE, allres = FALSE, ... )

# S3 method for formula coxplsDR( Xplan, time, time2, event, type, origin, typeres = "deviance", collapse, weighted, scaleX = TRUE, scaleY = TRUE, ncomp = min(7, ncol(Xplan)), modepls = "regression", plot = FALSE, allres = FALSE, dataXplan = NULL, subset, weights, model_frame = FALSE, model_matrix = FALSE, contrasts.arg = NULL, ... )

Arguments

Value

If allres=FALSE :

cox_plsDR

Final Cox-model.

If allres=TRUE :

tt_plsDR

PLSR components.

cox_plsDR

Final Cox-model.

plsDR_mod

The PLSR model.

Details

If allres=FALSE returns only the final Cox-model. If allres=TRUE returns a list with the PLS components, the final Cox-model and the PLSR model. allres=TRUE is useful for evluating model prediction accuracy on a test sample.

References

plsRcox, Cox-Models in a high dimensional setting in R, Frederic Bertrand, Philippe Bastien, Nicolas Meyer and Myriam Maumy-Bertrand (2014). Proceedings of User2014!, Los Angeles, page 152.

Deviance residuals-based sparse PLS and sparse kernel PLS regression for censored data, Philippe Bastien, Frederic Bertrand, Nicolas Meyer and Myriam Maumy-Bertrand (2015), Bioinformatics, 31(3):397-404, doi:10.1093/bioinformatics/btu660.

See Also

coxph, plsr

Examples

Run this code

data(micro.censure)
data(Xmicro.censure_compl_imp)

X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
X_train_micro_df <- data.frame(X_train_micro)
Y_train_micro <- micro.censure$survyear[1:80]
C_train_micro <- micro.censure$DC[1:80]

(cox_plsDR_fit=coxplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6))
(cox_plsDR_fit2=coxplsDR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6))
(cox_plsDR_fit3=coxplsDR(~.,Y_train_micro,C_train_micro,ncomp=6,dataXplan=X_train_micro_df))

rm(X_train_micro,Y_train_micro,C_train_micro,cox_plsDR_fit,cox_plsDR_fit2,cox_plsDR_fit3)

Run the code above in your browser using DataLab