Learn R Programming

plsRcox (version 1.7.0)

cv.coxsplsDR: Cross-validating a splsDR-Model

Description

This function cross-validates coxsplsDR models. It only computes the recommended iAUCSurvROC criterion. Set allCVcrit=TRUE to retrieve the 13 other ones.

Usage

cv.coxsplsDR(data, method = c("efron", "breslow"), nfold = 5, nt = 10, eta=.5, 
plot.it = TRUE, se = TRUE, givefold, scaleX = TRUE, scaleY = FALSE, 
folddetails=FALSE, allCVcrit=FALSE, details=FALSE, namedataset="data", 
save=FALSE, verbose=TRUE,...)

Arguments

data
A list of three items:
  • xthe explanatory variables passed tocoxsplsDR'sXplanargument,
time passed to

Value

  • ntThe number of components requested
  • cv.error1Vector with the mean values, across folds, of, per fold unit, Cross-validated log-partial-likelihood for models with 0 to nt components.
  • cv.error2Vector with the mean values, across folds, of, per fold unit, van Houwelingen Cross-validated log-partial-likelihood for models with 0 to nt components.
  • cv.error3Vector with the mean values, across folds, of iAUC_CD for models with 0 to nt components.
  • cv.error4Vector with the mean values, across folds, of iAUC_hc for models with 0 to nt components.
  • cv.error5Vector with the mean values, across folds, of iAUC_sh for models with 0 to nt components.
  • cv.error6Vector with the mean values, across folds, of iAUC_Uno for models with 0 to nt components.
  • cv.error7Vector with the mean values, across folds, of iAUC_hz.train for models with 0 to nt components.
  • cv.error8Vector with the mean values, across folds, of iAUC_hz.test for models with 0 to nt components.
  • cv.error9Vector with the mean values, across folds, of iAUC_survivalROC.train for models with 0 to nt components.
  • cv.error10Vector with the mean values, across folds, of iAUC_survivalROC.test for models with 0 to nt components.
  • cv.error11Vector with the mean values, across folds, of iBrierScore unw for models with 0 to nt components.
  • cv.error12Vector with the mean values, across folds, of iSchmidScore (robust BS) unw for models with 0 to nt components.
  • cv.error13Vector with the mean values, across folds, of iBrierScore w for models with 0 to nt components.
  • cv.error14Vector with the mean values, across folds, of iSchmidScore (robust BS) w for models with 0 to nt components.
  • cv.se1Vector with the standard error values, across folds, of, per fold unit, Cross-validated log-partial-likelihood for models with 0 to nt components.
  • cv.se2Vector with the standard error values, across folds, of, per fold unit, van Houwelingen Cross-validated log-partial-likelihood for models with 0 to nt components.
  • cv.se3Vector with the standard error values, across folds, of iAUC_CD for models with 0 to nt components.
  • cv.se4Vector with the standard error values, across folds, of iAUC_hc for models with 0 to nt components.
  • cv.se5Vector with the standard error values, across folds, of iAUC_sh for models with 0 to nt components.
  • cv.se6Vector with the standard error values, across folds, of iAUC_Uno for models with 0 to nt components.
  • cv.se7Vector with the standard error values, across folds, of iAUC_hz.train for models with 0 to nt components.
  • cv.se8Vector with the standard error values, across folds, of iAUC_hz.test for models with 0 to nt components.
  • cv.se9Vector with the standard error values, across folds, of iAUC_survivalROC.train for models with 0 to nt components.
  • cv.se10Vector with the standard error values, across folds, of iAUC_survivalROC.test for models with 0 to nt components.
  • cv.se11Vector with the standard error values, across folds, of iBrierScore unw for models with 0 to nt components.
  • cv.se12Vector with the standard error values, across folds, of iSchmidScore (robust BS) unw for models with 0 to nt components.
  • cv.se13Vector with the standard error values, across folds, of iBrierScore w for models with 0 to nt components.
  • cv.se14Vector with the standard error values, across folds, of iSchmidScore (robust BS) w for models with 0 to nt components.
  • foldsExplicit list of the values that were omited values in each fold.
  • lambda.min1Vector with the standard error values, across folds, of, per fold unit, Cross-validated log-partial-likelihood for models with 0 to nt components.
  • lambda.min2Vector with the standard error values, across folds, of, per fold unit, van Houwelingen Cross-validated log-partial-likelihood for models with 0 to nt components.
  • lambda.min1Optimal Nbr of components, min Cross-validated log-partial-likelihood criterion.
  • lambda.se1Optimal Nbr of components, min+1se Cross-validated log-partial-likelihood criterion.
  • lambda.min2Optimal Nbr of components, min van Houwelingen Cross-validated log-partial-likelihood.
  • lambda.se2Optimal Nbr of components, min+1se van Houwelingen Cross-validated log-partial-likelihood.
  • lambda.min3Optimal Nbr of components, max iAUC_CD criterion.
  • lambda.se3Optimal Nbr of components, max+1se iAUC_CD criterion.
  • lambda.min4Optimal Nbr of components, max iAUC_hc criterion.
  • lambda.se4Optimal Nbr of components, max+1se iAUC_hc criterion.
  • lambda.min5Optimal Nbr of components, max iAUC_sh criterion.
  • lambda.se5Optimal Nbr of components, max+1se iAUC_sh criterion.
  • lambda.min6Optimal Nbr of components, max iAUC_Uno criterion.
  • lambda.se6Optimal Nbr of components, max+1se iAUC_Uno criterion.
  • lambda.min7Optimal Nbr of components, max iAUC_hz.train criterion.
  • lambda.se7Optimal Nbr of components, max+1se iAUC_hz.train criterion.
  • lambda.min8Optimal Nbr of components, max iAUC_hz.test criterion.
  • lambda.se8Optimal Nbr of components, max+1se iAUC_hz.test criterion.
  • lambda.min9Optimal Nbr of components, max iAUC_survivalROC.train criterion.
  • lambda.se9Optimal Nbr of components, max+1se iAUC_survivalROC.train criterion.
  • lambda.min10Optimal Nbr of components, max iAUC_survivalROC.test criterion.
  • lambda.se10Optimal Nbr of components, max+1se iAUC_survivalROC.test criterion.
  • lambda.min11Optimal Nbr of components, min iBrierScore unw criterion.
  • lambda.se11Optimal Nbr of components, min+1se iBrierScore unw criterion.
  • lambda.min12Optimal Nbr of components, min iSchmidScore unw criterion.
  • lambda.se12Optimal Nbr of components, min+1se iSchmidScore unw criterion.
  • lambda.min13Optimal Nbr of components, min iBrierScore w criterion.
  • lambda.se13Optimal Nbr of components, min+1se iBrierScore w criterion.
  • lambda.min14Optimal Nbr of components, min iSchmidScore w criterion.
  • lambda.se14Optimal Nbr of components, min+1se iSchmidScore w criterion.
  • errormat1-14If details=TRUE, matrices with the error values for every folds across each of the components and each of the criteria
  • completed.cv1-14If details=TRUE, matrices with logical values for every folds across each of the components and each of the criteria: TRUE if the computation was completed and FALSE it is failed.
  • All_indicsAll results of the functions that perform error computation, for each fold, each component and error criterion.

item

  • method
  • nfold
  • nt
  • eta
  • plot.it
  • se
  • givefold
  • scaleX
  • scaleY
  • folddetails
  • allCVcrit
  • details
  • namedataset
  • save
  • verbose
  • ...

References

Frederic Bertrand, Philippe Bastien, Nicolas Meyer and Myriam Maumy-Bertrand. plsRcox, Cox-Models in a high dimensional setting in R. UseR 2014. Los Angeles. USA.

See Also

See Also coxsplsDR

Examples

Run this code
data(micro.censure)
data(Xmicro.censure_compl_imp)
set.seed(123456)
X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
X_train_micro_df <- data.frame(X_train_micro)
Y_train_micro <- micro.censure$survyear[1:80]
C_train_micro <- micro.censure$DC[1:80]

#Should be run with a higher value of nt (at least 10) and a grid of eta
(cv.coxplsDR.res=cv.coxsplsDR(list(x=X_train_micro,time=Y_train_micro,
status=C_train_micro),nt=3,eta=.1))

Run the code above in your browser using DataLab