This function cross-validates larsDR_coxph models.
cv.larsDR(
data,
method = c("efron", "breslow"),
nfold = 5,
fraction = seq(0, 1, length = 100),
plot.it = TRUE,
se = TRUE,
givefold,
scaleX = TRUE,
scaleY = FALSE,
folddetails = FALSE,
allCVcrit = FALSE,
details = FALSE,
namedataset = "data",
save = FALSE,
verbose = TRUE,
...
)The number of components requested
Vector with the mean values, across folds, of, per fold unit, Cross-validated log-partial-likelihood for models with 0 to nt components.
Vector with the mean values, across folds, of, per fold unit, van Houwelingen Cross-validated log-partial-likelihood for models with 0 to nt components.
Vector with the mean values, across folds, of iAUC_CD for models with 0 to nt components.
Vector with the mean values, across folds, of iAUC_hc for models with 0 to nt components.
Vector with the mean values, across folds, of iAUC_sh for models with 0 to nt components.
Vector with the mean values, across folds, of iAUC_Uno for models with 0 to nt components.
Vector with the mean values, across folds, of iAUC_hz.train for models with 0 to nt components.
Vector with the mean values, across folds, of iAUC_hz.test for models with 0 to nt components.
Vector with the mean values, across folds, of iAUC_survivalROC.train for models with 0 to nt components.
Vector with the mean values, across folds, of iAUC_survivalROC.test for models with 0 to nt components.
Vector with the mean values, across folds, of iBrierScore unw for models with 0 to nt components.
Vector with the mean values, across folds, of iSchmidScore (robust BS) unw for models with 0 to nt components.
Vector with the mean values, across folds, of iBrierScore w for models with 0 to nt components.
Vector with the mean values, across folds, of iSchmidScore (robust BS) w for models with 0 to nt components.
Vector with the standard error values, across folds, of, per fold unit, Cross-validated log-partial-likelihood for models with 0 to nt components.
Vector with the standard error values, across folds, of, per fold unit, van Houwelingen Cross-validated log-partial-likelihood for models with 0 to nt components.
Vector with the standard error values, across folds, of iAUC_CD for models with 0 to nt components.
Vector with the standard error values, across folds, of iAUC_hc for models with 0 to nt components.
Vector with the standard error values, across folds, of iAUC_sh for models with 0 to nt components.
Vector with the standard error values, across folds, of iAUC_Uno for models with 0 to nt components.
Vector with the standard error values, across folds, of iAUC_hz.train for models with 0 to nt components.
Vector with the standard error values, across folds, of iAUC_hz.test for models with 0 to nt components.
Vector with the standard error values, across folds, of iAUC_survivalROC.train for models with 0 to nt components.
Vector with the standard error values, across folds, of iAUC_survivalROC.test for models with 0 to nt components.
Vector with the standard error values, across folds, of iBrierScore unw for models with 0 to nt components.
Vector with the standard error values, across folds, of iSchmidScore (robust BS) unw for models with 0 to nt components.
Vector with the standard error values, across folds, of iBrierScore w for models with 0 to nt components.
Vector with the standard error values, across folds, of iSchmidScore (robust BS) w for models with 0 to nt components.
Explicit list of the values that were omited values in each fold.
Vector with the standard error values, across folds, of, per fold unit, Cross-validated log-partial-likelihood for models with 0 to nt components.
Vector with the standard error values, across folds, of, per fold unit, van Houwelingen Cross-validated log-partial-likelihood for models with 0 to nt components.
Optimal Nbr of components, min Cross-validated log-partial-likelihood criterion.
Optimal Nbr of components, min+1se Cross-validated log-partial-likelihood criterion.
Optimal Nbr of components, min van Houwelingen Cross-validated log-partial-likelihood.
Optimal Nbr of components, min+1se van Houwelingen Cross-validated log-partial-likelihood.
Optimal Nbr of components, max iAUC_CD criterion.
Optimal Nbr of components, max+1se iAUC_CD criterion.
Optimal Nbr of components, max iAUC_hc criterion.
Optimal Nbr of components, max+1se iAUC_hc criterion.
Optimal Nbr of components, max iAUC_sh criterion.
Optimal Nbr of components, max+1se iAUC_sh criterion.
Optimal Nbr of components, max iAUC_Uno criterion.
Optimal Nbr of components, max+1se iAUC_Uno criterion.
Optimal Nbr of components, max iAUC_hz.train criterion.
Optimal Nbr of components, max+1se iAUC_hz.train criterion.
Optimal Nbr of components, max iAUC_hz.test criterion.
Optimal Nbr of components, max+1se iAUC_hz.test criterion.
Optimal Nbr of components, max iAUC_survivalROC.train criterion.
Optimal Nbr of components, max+1se iAUC_survivalROC.train criterion.
Optimal Nbr of components, max iAUC_survivalROC.test criterion.
Optimal Nbr of components, max+1se iAUC_survivalROC.test criterion.
Optimal Nbr of components, min iBrierScore unw criterion.
Optimal Nbr of components, min+1se iBrierScore unw criterion.
Optimal Nbr of components, min iSchmidScore unw criterion.
Optimal Nbr of components, min+1se iSchmidScore unw criterion.
Optimal Nbr of components, min iBrierScore w criterion.
Optimal Nbr of components, min+1se iBrierScore w criterion.
Optimal Nbr of components, min iSchmidScore w criterion.
Optimal Nbr of components, min+1se iSchmidScore w criterion.
If
details=TRUE, matrices with the error values for every folds across
each of the components and each of the criteria
If
details=TRUE, matrices with logical values for every folds across
each of the components and each of the criteria: TRUE if the
computation was completed and FALSE it is failed.
Lars model fitted on the residuals.
All results of the functions that perform error computation, for each fold, each component and error criterion.
It only computes the recommended van Houwelingen CV partial likelihood
criterion criterion. Set allCVcrit=TRUE to retrieve the 13 other
ones.
plsRcox, Cox-Models in a high dimensional setting in R, Frederic
Bertrand, Philippe Bastien, Nicolas Meyer and Myriam Maumy-Bertrand (2014).
Proceedings of User2014!, Los Angeles, page 152.
Deviance residuals-based sparse PLS and sparse kernel PLS regression for censored data, Philippe Bastien, Frederic Bertrand, Nicolas Meyer and Myriam Maumy-Bertrand (2015), Bioinformatics, 31(3):397-404, doi:10.1093/bioinformatics/btu660.
See Also larsDR_coxph
data(micro.censure)
data(Xmicro.censure_compl_imp)
set.seed(123456)
X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
X_train_micro_df <- data.frame(X_train_micro)
Y_train_micro <- micro.censure$survyear[1:80]
C_train_micro <- micro.censure$DC[1:80]
#Should be run with the default: fraction = seq(0, 1, length = 100)
(cv.larsDR.res=cv.larsDR(list(x=X_train_micro,time=Y_train_micro,
status=C_train_micro),se=TRUE,fraction=seq(0, 1, length = 4)))
Run the code above in your browser using DataLab