View source: R/summary.plsRcoxmodel.R
| summary.plsRcoxmodel | R Documentation |
This function provides a summary method for the class "plsRcoxmodel"
## S3 method for class 'plsRcoxmodel'
summary(object, ...)
object |
an object of the class |
... |
further arguments to be passed to or from methods. |
call |
function call of plsRcox models |
Frédéric Bertrand
frederic.bertrand@lecnam.net
https://fbertran.github.io/homepage/
plsRcox, Cox-Models in a high dimensional setting in R, Frederic
Bertrand, Philippe Bastien, Nicolas Meyer and Myriam Maumy-Bertrand (2014).
Proceedings of User2014!, Los Angeles, page 152.
Deviance residuals-based sparse PLS and sparse kernel PLS regression for censored data, Philippe Bastien, Frederic Bertrand, Nicolas Meyer and Myriam Maumy-Bertrand (2015), Bioinformatics, 31(3):397-404, doi:10.1093/bioinformatics/btu660.
summary
data(micro.censure)
data(Xmicro.censure_compl_imp)
X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
Y_train_micro <- micro.censure$survyear[1:80]
C_train_micro <- micro.censure$DC[1:80]
modpls <- plsRcox(X_train_micro,time=Y_train_micro,event=C_train_micro,nt=3)
summary(modpls)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.