Learn R Programming

plsRcox (version 1.8.2)

DKplsRcox: Partial least squares Regression generalized linear models

Description

This function implements an extension of Partial least squares Regression to Cox Models.

Usage

DKplsRcox(Xplan, ...)

DKplsRcoxmodel(Xplan, ...)

# S3 method for default DKplsRcoxmodel( Xplan, time, time2, event, type, origin, typeres = "deviance", collapse, weighted, scaleX = TRUE, scaleY = TRUE, nt = min(2, ncol(Xplan)), limQ2set = 0.0975, dataPredictY = Xplan, pvals.expli = FALSE, alpha.pvals.expli = 0.05, tol_Xi = 10^(-12), weights, control, sparse = FALSE, sparseStop = TRUE, plot = FALSE, allres = FALSE, kernel = "rbfdot", hyperkernel, verbose = TRUE, ... )

# S3 method for formula DKplsRcoxmodel( Xplan, time, time2, event, type, origin, typeres = "deviance", collapse, weighted, scaleX = TRUE, scaleY = NULL, dataXplan = NULL, nt = min(2, ncol(Xplan)), limQ2set = 0.0975, dataPredictY = Xplan, pvals.expli = FALSE, model_frame = FALSE, alpha.pvals.expli = 0.05, tol_Xi = 10^(-12), weights, subset, control, sparse = FALSE, sparseStop = TRUE, plot = FALSE, allres = FALSE, kernel = "rbfdot", hyperkernel, verbose = TRUE, model_matrix = FALSE, contrasts.arg = NULL, ... )

Arguments

Value

Depends on the model that was used to fit the model.

Details

A typical predictor has the form response ~ terms where response is the (numeric) response vector and terms is a series of terms which specifies a linear predictor for response. A terms specification of the form first + second indicates all the terms in first together with all the terms in second with any duplicates removed.

A specification of the form first:second indicates the the set of terms obtained by taking the interactions of all terms in first with all terms in second. The specification first*second indicates the cross of first and second. This is the same as first + second + first:second.

The terms in the formula will be re-ordered so that main effects come first, followed by the interactions, all second-order, all third-order and so on: to avoid this pass a terms object as the formula.

Non-NULL weights can be used to indicate that different observations have different dispersions (with the values in weights being inversely proportional to the dispersions); or equivalently, when the elements of weights are positive integers w_i, that each response y_i is the mean of w_i unit-weight observations.

References

plsRcox, Cox-Models in a high dimensional setting in R, Frederic Bertrand, Philippe Bastien, Nicolas Meyer and Myriam Maumy-Bertrand (2014). Proceedings of User2014!, Los Angeles, page 152.

Deviance residuals-based sparse PLS and sparse kernel PLS regression for censored data, Philippe Bastien, Frederic Bertrand, Nicolas Meyer and Myriam Maumy-Bertrand (2015), Bioinformatics, 31(3):397-404, doi:10.1093/bioinformatics/btu660.

See Also

plsR and plsRglm

Examples

Run this code

data(micro.censure)
data(Xmicro.censure_compl_imp)

X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
X_train_micro_df <- data.frame(X_train_micro)
Y_train_micro <- micro.censure$survyear[1:80]
C_train_micro <- micro.censure$DC[1:80]

# \donttest{
DKplsRcox(X_train_micro,time=Y_train_micro,event=C_train_micro,nt=5)
DKplsRcox(~X_train_micro,time=Y_train_micro,event=C_train_micro,nt=5)
# }

# \donttest{
DKplsRcox(Xplan=X_train_micro,time=Y_train_micro,event=C_train_micro,nt=5,sparse=TRUE, 
alpha.pvals.expli=.15)
DKplsRcox(Xplan=~X_train_micro,time=Y_train_micro,event=C_train_micro,nt=5,sparse=TRUE,
alpha.pvals.expli=.15)
# }

Run the code above in your browser using DataLab