Learn R Programming

plsRcox (version 1.8.2)

coxsplsDR: Fitting a sPLSR model on the (Deviance) Residuals

Description

This function computes the Cox Model based on sPLSR components computed model with

  • as the response: the Residuals of a Cox-Model fitted with no covariate

  • as explanatory variables: Xplan.

It uses the package spls to perform the first step in SPLSR then mixOmics to perform PLSR step fit.

Usage

coxsplsDR(Xplan, ...)

# S3 method for default coxsplsDR( Xplan, time, time2, event, type, origin, typeres = "deviance", collapse, weighted, scaleX = TRUE, scaleY = TRUE, ncomp = min(7, ncol(Xplan)), modepls = "regression", plot = FALSE, allres = FALSE, eta = 0.5, trace = FALSE, ... )

# S3 method for formula coxsplsDR( Xplan, time, time2, event, type, origin, typeres = "deviance", collapse, weighted, scaleX = TRUE, scaleY = TRUE, ncomp = min(7, ncol(Xplan)), modepls = "regression", plot = FALSE, allres = FALSE, dataXplan = NULL, subset, weights, model_frame = FALSE, eta = 0.5, trace = FALSE, model_matrix = FALSE, contrasts.arg = NULL, ... )

Arguments

Value

If allres=FALSE :

cox_splsDR

Final Cox-model.

If allres=TRUE :

tt_splsDR

sPLSR components.

cox_splsDR

Final Cox-model.

splsDR_mod

The sPLSR model.

Details

If allres=FALSE returns only the final Cox-model. If allres=TRUE returns a list with the sPLS components, the final Cox-model and the sPLSR model. allres=TRUE is useful for evluating model prediction accuracy on a test sample.

References

plsRcox, Cox-Models in a high dimensional setting in R, Frederic Bertrand, Philippe Bastien, Nicolas Meyer and Myriam Maumy-Bertrand (2014). Proceedings of User2014!, Los Angeles, page 152.

Deviance residuals-based sparse PLS and sparse kernel PLS regression for censored data, Philippe Bastien, Frederic Bertrand, Nicolas Meyer and Myriam Maumy-Bertrand (2015), Bioinformatics, 31(3):397-404, doi:10.1093/bioinformatics/btu660.

See Also

coxph, plsr

Examples

Run this code

data(micro.censure)
data(Xmicro.censure_compl_imp)

X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
X_train_micro_df <- data.frame(X_train_micro)
Y_train_micro <- micro.censure$survyear[1:80]
C_train_micro <- micro.censure$DC[1:80]

(cox_splsDR_fit=coxsplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,eta=.5))
(cox_splsDR_fit2=coxsplsDR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,eta=.5,trace=TRUE))
(cox_splsDR_fit3=coxsplsDR(~.,Y_train_micro,C_train_micro,ncomp=6,
dataXplan=X_train_micro_df,eta=.5))

rm(X_train_micro,Y_train_micro,C_train_micro,cox_splsDR_fit,cox_splsDR_fit2,cox_splsDR_fit3)

Run the code above in your browser using DataLab