allCVcrit=TRUE
to retrieve the 13 other ones.cv.coxsplsDR(data, method = c("efron", "breslow"), nfold = 5, nt = 10, eta=.5,
plot.it = TRUE, se = TRUE, givefold, scaleX = TRUE, scaleY = FALSE,
folddetails=FALSE, allCVcrit=FALSE, details=FALSE, namedataset="data",
save=FALSE, verbose=TRUE,...)xthe explanatory variables passed tocoxsplsDR'sXplanargument,time passed to details=TRUE, matrices with the error values for every folds across each of the components and each of the criteriadetails=TRUE, matrices with logical values for every folds across each of the components and each of the criteria: TRUE if the computation was completed and FALSE it is failed.coxsplsDRcoxsplsDRdata(micro.censure)
data(Xmicro.censure_compl_imp)
set.seed(123456)
X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
X_train_micro_df <- data.frame(X_train_micro)
Y_train_micro <- micro.censure$survyear[1:80]
C_train_micro <- micro.censure$DC[1:80]
#Should be run with a higher value of nt (at least 10) and a grid of eta
(cv.coxplsDR.res=cv.coxsplsDR(list(x=X_train_micro,time=Y_train_micro,
status=C_train_micro),nt=3,eta=.1))Run the code above in your browser using DataLab